==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_sr.ts <==
<TS language="sr" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Napravite novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopirajte trenutno izabranu adresu</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Kopirajte</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izbrisite trenutno izabranu adresu sa liste</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Избриши</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Унесите лозинку</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова лозинка</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Поновите нову лозинку</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Општи преглед</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Погледајте општи преглед новчаника</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Претражите историјат трансакција</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>I&amp;zlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Напустите програм</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>П&amp;оставке...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Шифровање новчаника...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Промени &amp;лозинку...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Мењање лозинке којом се шифрује новчаник</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>новчаник</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Пошаљи</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Фајл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Подешавања</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>П&amp;омоћ</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ажурно</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ажурирање у току...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Послана трансакција</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Придошла трансакција</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Новчаник јс &lt;b&gt;шифрован&lt;/b&gt; и тренутно &lt;b&gt;закључан&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>iznos</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>datum</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrdjen</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Измени адресу</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Етикета</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Адреса</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Јединица за приказивање износа:</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Слање новца</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Потврди акцију слања</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Пошаљи</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Етикета</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+П</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+П</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ovaj odeljak pokazuje detaljan opis transakcije</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading addresses...</source>
        <translation>učitavam adrese....</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljno sredstava</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Učitavam blok indeksa...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Новчаник се учитава...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovo skeniram...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Završeno učitavanje</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_sr.ts <==
<TS language="sr" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Napravite novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopirajte trenutno izabranu adresu</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Kopirajte</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izbrisite trenutno izabranu adresu sa liste</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Избриши</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Унесите лозинку</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова лозинка</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Поновите нову лозинку</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>новчаник</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Општи преглед</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Погледајте општи преглед новчаника</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Пошаљи</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Претражите историјат трансакција</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>I&amp;zlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Напустите програм</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>П&amp;оставке...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Шифровање новчаника...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Промени &amp;лозинку...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Мењање лозинке којом се шифрује новчаник</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Фајл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Подешавања</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>П&amp;омоћ</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ажурно</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ажурирање у току...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Послана трансакција</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Придошла трансакција</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Новчаник јс &lt;b&gt;шифрован&lt;/b&gt; и тренутно &lt;b&gt;закључан&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>iznos</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>datum</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrdjen</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Измени адресу</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Етикета</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Адреса</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Јединица за приказивање износа:</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Слање новца</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Потврди акцију слања</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Пошаљи</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Poruka:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Етикета</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+П</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+П</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ovaj odeljak pokazuje detaljan opis transakcije</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading addresses...</source>
        <translation>učitavam adrese....</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljno sredstava</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Učitavam blok indeksa...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Новчаник се учитава...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovo skeniram...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Završeno učitavanje</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
</TS>
